/**
 * @file
 * Provides Zooming loader.
 */

(function (Drupal, _db, window, document) {

  'use strict';

  /**
   * Toggle zooming classes.
   *
   * @param {HTMLElement} target
   *   The target HTML element.
   * @param {Bool} isOpen
   *   If it is zooming.
   */
  function toggleClasses(target, isOpen) {
    document.body.classList[isOpen ? 'add' : 'remove']('is-zooming');

    _db.forEach(['.content', '.field__item', '.grid', '.slide'], function (sel) {
      var pel = _db.closest(target, sel);
      if (pel != null) {
        pel.classList[isOpen ? 'add' : 'remove']('is-zooming__zoomed');
      }
    });
  }

  /**
   * Zooming utility functions.
   *
   * @param {HTMLElement} elm
   *   The Zooming HTML element.
   */
  function doZooming(elm) {
    var options = {
      onImageLoading: function (target) {
        toggleClasses(target, true);
        document.body.classList.add('is-zooming--loading');
      },
      onImageLoaded: function (target) {
        document.body.classList.remove('is-zooming--loading');
      },
      onOpen: function (target) {
        toggleClasses(target, true);
        document.body.classList.add('is-zooming--open');
      },
      onClose: function (target) {
        toggleClasses(target, false);
        document.body.classList.remove('is-zooming--open');
        target.removeAttribute('style');
      }
    };
    new Zooming(options).listen('.media__zooming');
  }

  /**
   * Attaches zooming behavior to HTML element.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.zooming = {
    attach: function (context) {
      var items = context.querySelectorAll('[data-zooming-trigger], .zooming');
      _db.once(_db.forEach(items, doZooming));
    }
  };

})(Drupal, dBlazy, this, this.document);
